package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcPartyA;

/**
 * cmc业主单位Mapper接口
 * 
 * @author cmc
 * @date 2024-06-12
 */
public interface CmcPartyAMapper 
{
    /**
     * 查询cmc业主单位
     * 
     * @param partyAId cmc业主单位主键
     * @return cmc业主单位
     */
    public CmcPartyA selectCmcPartyAByPartyAId(String partyAId);

    /**
     * 查询cmc业主单位列表
     * 
     * @param cmcPartyA cmc业主单位
     * @return cmc业主单位集合
     */
    public List<CmcPartyA> selectCmcPartyAList(CmcPartyA cmcPartyA);

    /**
     * 新增cmc业主单位
     * 
     * @param cmcPartyA cmc业主单位
     * @return 结果
     */
    public int insertCmcPartyA(CmcPartyA cmcPartyA);

    /**
     * 修改cmc业主单位
     * 
     * @param cmcPartyA cmc业主单位
     * @return 结果
     */
    public int updateCmcPartyA(CmcPartyA cmcPartyA);

    /**
     * 删除cmc业主单位
     * 
     * @param partyAId cmc业主单位主键
     * @return 结果
     */
    public int deleteCmcPartyAByPartyAId(String partyAId);

    /**
     * 批量删除cmc业主单位
     * 
     * @param partyAIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcPartyAByPartyAIds(String[] partyAIds);
}
